@@ -131,7 +131,8 @@ class LoginRequest(DSRequest):
         tetatet_chats_sender = []
         tetatet_chats = []
 
-        settings.LOCKS.acquire('LoginRequest.get_chats')
+        key='LoginRequest.get_chats'
+        settings.LOCKS.acquire(key)
         for chat in Chat_user_user.objects.filter(user_reciver=user):
             tetatet_chats_reciver.append(dict(
                 id=chat.common_id,
@@ -194,7 +195,7 @@ class LoginRequest(DSRequest):
                             description='Группа создана автоматически'))[0].id
                 ],
             ) for chat_users in Chat_usersView.objects.filter(user=user)]
-        settings.LOCKS.release('LoginRequest.get_chats')
+        settings.LOCKS.release(key)
 
         return dict(
             group_chats=group_chats,
@@ -206,7 +207,8 @@ class LoginRequest(DSRequest):
         _user = user
         _bot = bot
 
-        settings.LOCKS.acquire('LoginRequest.send_bot_message')
+        key='LoginRequest.send_bot_message'
+        settings.LOCKS.acquire(key)
         if not isinstance(_user, User) and isinstance(_user, int):
             _user = User.objects.get(id=_user)
 
@@ -270,4 +272,4 @@ class LoginRequest(DSRequest):
                 ChatsManager.refresh_chat_menu(user=_user, logger=logger)
                 time.sleep(3)
             send()
-        settings.LOCKS.release('LoginRequest.send_bot_message')
+        settings.LOCKS.release(key)
