@@ -1,3 +1,5 @@
+from decimal import Decimal
+
 from bitfield import BitHandler, Bit
 
 from isc_common import setAttr
@@ -39,6 +41,25 @@ def StrToNumber(s1):
             return None
 
 
+def IntToNumber(s):
+    if s == None:
+        return None
+
+    if not isinstance(s, int):
+        raise Exception(f'{s} is not int type.')
+
+    return float(s)
+
+def IntToDecimal(s):
+    if s == None:
+        return None
+
+    if not isinstance(s, int):
+        raise Exception(f'{s} is not int type.')
+
+    return Decimal(s)
+
+
 def StrToInt(s):
     if s == None:
         return None
